@@ -1,15 +1,29 @@
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# auth: metagriffin <metagriffin@uberdev.org>
+# auth: metagriffin <mg.github@uberdev.org>
 # date: 2013/11/05
-# copy: (C) CopyLoose 2013 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2013-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
 #------------------------------------------------------------------------------
 
 import sys, os, argparse, logging, signal, threading, pickle, subprocess
 import pwd, grp
 from aadict import aadict
 
+from . import framework
 from .util import SvnpublishLogFormatter
 from .i18n import _
 
@@ -70,13 +84,14 @@ class Daemon(object):
   def handleTask(self, taskid):
     log.info('handling task: %s', taskid)
     fname = os.path.join(self.taskdir, taskid)
-    dname = os.path.join(self.taskdir, 'work-' + taskid)
+    dname = os.path.join(self.taskdir, 'processing-' + taskid)
     with open(fname, 'rb') as fp:
       task = pickle.load(fp)
     os.rename(fname, dname)
     try:
       self.launchTask(aadict(task))
       os.unlink(dname)
+      log.info('task complete: %s', taskid)
     except Exception:
       log.exception('failed during handling of task %s', taskid)
       # todo: ideally, this would email the admins...
@@ -160,6 +175,11 @@ def main(args=None):
     description = _('Asynchronous svnpublish daemon')
     )
 
+  cli.add_argument(
+    _('-V'), _('--version'),
+    dest='version', default=False, action='store_true',
+    help=_('output current svnpublish version and exit'))
+
   cli.add_argument(
     _('-l'), _('--log-level'), metavar=_('LEVEL'),
     dest='loglvl', default='warning', action='store',
@@ -209,6 +229,10 @@ def main(args=None):
 
   options = cli.parse_args(args)
 
+  if options.version:
+    print framework.version
+    return 0
+
   # configure the logging
   logger  = logging.getLogger()
   handler = logging.StreamHandler(sys.stdout)
@@ -228,7 +252,8 @@ def main(args=None):
     logger.setLevel(0)
     return initServiceDir(options)
 
-  log.info('svnpublishd initializing (pid=%d, uid=%d)', os.getpid(), os.getuid())
+  log.info('svnpublishd v%s initializing (pid=%d, uid=%d)',
+           framework.version, os.getpid(), os.getuid())
   daemon = Daemon(options.svcdir, period=options.period)
   registerSignalHandlers(daemon)
   daemon.start()
