@@ -1,11 +1,22 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# desc: the last svn publishing tool that i will write...
-# auth: griffin <griffin@uberdev.org>
+# auth: metagriffin <mg.github@uberdev.org>
 # date: 2009/09/02
-# copy: (C) CopyLoose 2009 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2009-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
 #------------------------------------------------------------------------------
 
 '''
@@ -14,7 +25,7 @@ svnpublish engine.
 '''
 
 import sys, os, argparse, six, logging, yaml, traceback, pipes, pickle
-import time, uuid, subprocess
+import time, uuid, subprocess, pkg_resources
 from aadict import aadict
 
 from . import framework, api, revinfo, subversion, util
@@ -28,6 +39,11 @@ def main(args=None):
     description = _('Powerful automation from a subversion repository.'),
     )
 
+  cli.add_argument(
+    _('-V'), _('--version'),
+    dest='version', default=False, action='store_true',
+    help=_('output current svnpublish version and exit'))
+
   cli.add_argument(
     _('--init-options'),
     dest='initOptions', default=False, action='store_true',
@@ -114,6 +130,10 @@ def main(args=None):
 
   options = cli.parse_args(args)
 
+  if options.version:
+    print framework.version
+    return 0
+
   if options.initOptions:
     output = framework.defaultOptions.split('\n')
     for idx, line in enumerate(output):
@@ -188,6 +208,9 @@ def main(args=None):
   #----------------------------------------------------------------------------
   # setup the svnpublish options
 
+  logger.info('svnpublish v%s initializing (pid=%d, uid=%d)',
+              framework.version, os.getpid(), os.getuid())
+
   runoptions = aadict.d2ar(yaml.load(framework.defaultOptions))
 
   if options.options is not None:
