@@ -1,11 +1,22 @@
 # -*- coding: utf-8 -*-
 #------------------------------------------------------------------------------
 # file: $Id$
-# lib:  svnpublish.engine
-# desc: unit test for "email" svnpublish engine module
-# auth: griffin <griffin@uberdev.org>
+# auth: metagriffin <mg.github@uberdev.org>
 # date: 2011/05/14
-# copy: (C) CopyLoose 2011 UberDev <hardcore@uberdev.org>, No Rights Reserved.
+# copy: (C) Copyright 2011-EOT metagriffin -- see LICENSE.txt
+#------------------------------------------------------------------------------
+# This software is free software: you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation, either version 3 of the
+# License, or (at your option) any later version.
+#
+# This software is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see http://www.gnu.org/licenses/.
 #------------------------------------------------------------------------------
 
 import sys, unittest, os, yaml, logging, six, genemail
@@ -117,6 +128,10 @@ Detail
     @@ -1 +1 @@
     -this is a sample textfile.txt.
     +this is a sample textfile.txt with changes.
+    ''' + '''
+    ''' + '''
+
+Generated by svnpublish/v{version} on 2009-02-13T23:31:30Z.
 
 --==MIMEBOUNDARY=z1-alt-2==
 MIME-Version: 1.0
@@ -126,7 +141,8 @@ Content-Transfer-Encoding: 7bit
 <html xmlns="http://www.w3.org/1999/xhtml" lang="en" xml:lang="en">
  <head>
   <title>[SVN|TESTLABEL] r3 by svnuser - simple update with text changes</title>
-  <base href="https://svn.example.com/repos" />
+  <base href="https://svn.example.com/repos"/>
+  <meta name="generator" content="svnpublish/v{version}"/>
  </head>
  <body>
   <div class="clamp" style="background: #fff;font: 10pt &quot;Trebuchet MS&quot;, lucida, geneva, verdana, sans-serif">
@@ -332,12 +348,17 @@ Content-Transfer-Encoding: 7bit
       </td>
      </tr>
     </table>
+    <div class="credits" style="margin-top: 1em;color: #999;font-size: 80%">
+     Generated by
+     svnpublish/v{version}
+     on 2009-02-13T23:31:30Z.
+    </div>
    </div>
   </div>
  </body>
 </html>
 --==MIMEBOUNDARY=z1-alt-2==--
-'''
+'''.format(version=framework.version)
 
     self.assertEqual(len(self.sender.emails), 1)
     eml = self.sender.emails[0]
@@ -408,6 +429,10 @@ Detail
     @@ -1 +1 @@
     -this is a sample textfile.txt.
     +this is a sample textfile.txt with changes.
+    ''' + '''
+    ''' + '''
+
+Generated by svnpublish/v{version} on 2009-02-13T23:31:30Z.
 
 --==MIMEBOUNDARY=z1-alt-2==
 MIME-Version: 1.0
@@ -418,6 +443,7 @@ Content-Transfer-Encoding: 7bit
  <head>
   <title>[SVN|TESTLABEL] r3 by svnuser - simple update with text changes</title>
   <base href="https://svn.example.com/repos"/>
+  <meta name="generator" content="svnpublish/v{version}"/>
  </head>
  <body>
   <div class="clamp" style="background: #fff;font: 10pt &quot;Trebuchet MS&quot;, lucida, geneva, verdana, sans-serif">
@@ -631,13 +657,18 @@ Content-Transfer-Encoding: 7bit
       </td>
      </tr>
     </table>
+    <div class="credits" style="margin-top: 1em;color: #999;font-size: 80%">
+     Generated by
+     svnpublish/v{version}
+     on 2009-02-13T23:31:30Z.
+    </div>
    </div>
   </div>
  </body>
 </html>
 
 --==MIMEBOUNDARY=z1-alt-2==--
-'''
+'''.format(version=framework.version)
 
     self.assertEqual(len(self.sender.emails), 1)
     self.assertEqual(self.sender.emails[0]['mailfrom'], 'noreply@localhost')
@@ -712,6 +743,10 @@ Detail
     @@ -1 +1 @@
     -this is a sample textfile.txt.
     +this is a sample textfile.txt with changes.
+    ''' + '''
+    ''' + '''
+
+Generated by svnpublish/v{version} on 2009-02-13T23:31:30Z.
 
 --==MIMEBOUNDARY=z1-alt-2==
 MIME-Version: 1.0
@@ -722,6 +757,7 @@ Content-Transfer-Encoding: 7bit
  <head>
   <title>[SVN|TESTLABEL] r3 by svnuser - simple update with text changes</title>
   <base href="https://svn.example.com/repos"/>
+  <meta name="generator" content="svnpublish/v{version}"/>
  </head>
  <body>
   <div class="clamp" style="background: #fff;font: 10pt &quot;Trebuchet MS&quot;, lucida, geneva, verdana, sans-serif">
@@ -935,13 +971,18 @@ Content-Transfer-Encoding: 7bit
       </td>
      </tr>
     </table>
+    <div class="credits" style="margin-top: 1em;color: #999;font-size: 80%">
+     Generated by
+     svnpublish/v{version}
+     on 2009-02-13T23:31:30Z.
+    </div>
    </div>
   </div>
  </body>
 </html>
 
 --==MIMEBOUNDARY=z1-alt-2==--
-'''
+'''.format(version=framework.version)
 
     self.assertEqual(len(self.sender.emails), 1)
     self.assertEqual(self.sender.emails[0]['mailfrom'], 'noreply@localhost')
